@@ -47,7 +47,7 @@ $YAHOO_CURRENCY_URL = "http://finance.yahoo.com/m5?";
 @EXPORT_OK = qw/yahoo yahoo_europe fidelity troweprice asx tiaacref/;
 @EXPORT_TAGS = ( all => [@EXPORT_OK]);
 
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 # Autoload method for obsolete methods.  This also allows people to
 # call methods that objects export without having to go through fetch.
@@ -64,7 +64,12 @@ sub AUTOLOAD {
 
 	if (exists($METHODS{$method})) {
 		eval qq[sub $method {
-			_dummy()->fetch("$method",\@_); 
+			my \$this;
+			if (ref \$_[0]) {
+				\$this = shift;
+			}
+			\$this ||= _dummy();
+			\$this->fetch("$method",\@_); 
 		}];
 		carp $@ if $@;
 		no strict 'refs';	# So we can use &$method
@@ -142,7 +147,8 @@ sub new {
 		shift if (scalar(@_));
 		# Default modules
 		 @modules = qw/Yahoo::Australia Fidelity ASX Troweprice
-                               Tiaacref Yahoo::USA Yahoo::Europe/;
+                               Tiaacref Yahoo::USA Yahoo::Europe
+			       DWS VWD Trustnet/;
 	}
 
 	$this->_load_modules(@modules,@_);
@@ -186,13 +192,15 @@ sub currency {
 	$from =~ s/^\s*(\d*\.?\d*)\s*//;
 	my $amount = $1 || 1;
 
-	my $ua = $this->user_agent;
-
 	# Don't know if these have to be in upper case, but it's
 	# better to be safe than sorry.
 	$to = uc($to);
 	$from = uc($from);
 
+	return $amount if ($from eq $to);	# Trivial case.
+
+	my $ua = $this->user_agent;
+
 	my $data = $ua->request(GET "${YAHOO_CURRENCY_URL}s=$from&t=$to")->content;
 	my ($exchange_rate) = $data =~ m#$from$to=X</a></td><td>1</td><td>[^<]+</td><td>(\d+\.\d+)</td>#;
 
@@ -406,7 +414,7 @@ sub fetch {
 	unless (exists $METHODS{$method}) {
 		carp "Undefined fetch-method $method passed to ".
 		     "Finance::Quote::fetch";
-		return undef;
+		return;
 	}
 
 	# Failover code.  This steps through all availabe methods while
@@ -434,8 +442,7 @@ sub fetch {
 		@stocks = @failed_stocks;
 	}
 
-
-	return %returnhash;
+	return wantarray() ? %returnhash : \%returnhash;
 }
 
 # =======================================================================
@@ -603,6 +610,7 @@ arguments are treated as stock-names.  In the standard Finance::Quote
 distribution, the following exchanges are recognised:
 
     australia		Australan Stock Exchange
+    dwsfunds		Deutsche Bank Gruppe funds
     fidelity		Fidelity Investments
     tiaacref		TIAA-CREF
     troweprice		T. Rowe Price
@@ -611,7 +619,9 @@ distribution, the following exchanges are recognised:
     usa			USA Markets
     nyse		New York Stock Exchange
     nasdaq		NASDAQ
+    uk_unit_trusts	UK Unit Trusts
     vanguard		Vanguard Investments
+    vwd			Vereinigte Wirtschaftsdienste GmbH
 
 When called in an array context, a hash is returned.  In a scalar
 context, a reference to a hash will be returned.  The structure
@@ -739,6 +749,8 @@ module.  Please refer to the sub-modules for further information.
   Yannick LE NY (C<y-le-ny@ifrance.com>)
   Paul Fenwick (C<pjf@schools.net.au>)
   Brent Neal (C<brentn@users.sourceforge.net>)
+  Volker Stuerzl (C<volker.stuerzl@gmx.de>)
+  Keith Refson (C<Keith.Refson#earth.ox.ac.uk>)
 
 The Finance::Quote home page can be found at
 http://finance-quote.sourceforge.net/
@@ -752,10 +764,12 @@ http://www.gnucash.org/
 =head1 SEE ALSO
 
 Finance::Quote::Yahoo, Finance::Quote::ASX, Finance::Quote::Fidelity,
-Finance::Quote::Tiaacref, Finance::Quote::Troweprice, LWP::UserAgent
+Finance::Quote::Tiaacref, Finance::Quote::Troweprice, LWP::UserAgent,
+Finance::Quote::DWS, Finance::Quote::VWD, Finance::Quote::Trustnet
 
 You should have also received the Finance::Quote hacker's guide with
 this package.  Please read it if you are interested in adding extra
-methods to this package.
+methods to this package.  The hacker's guide can also be found
+on the Finance::Quote website, http://finance-quote.sourceforge.net/
 
 =cut
